@@ -348,7 +348,9 @@ def alpha_16_ls(data = None, contravariant = 1., up_threshold = 0.8, low_thresho
     to_roll = to_roll.reset_index(drop = True)
     result_df = roll_corr(to_roll, window=lag)
     result_df = result_df.rank(pct = True)
-    correlated_rank = result_df.iloc[-1,0]
+    correlated_rank = 0
+    if result_df.shape[0]>0:
+        correlated_rank = result_df.iloc[-1,0]
     if correlated_rank >= up_threshold:
         return contravariant
     elif correlated_rank <= low_threshold:
@@ -376,7 +378,9 @@ def alpha_13_lo(data = None, contravariant = -1., up_threshold=0.8, lag = 5,  **
     result_df = roll_corr(to_roll, window=lag)
     result_df = result_df.dropna()
     result_df = result_df.rank(pct = True)
-    correlated_rank = result_df.iloc[-1, 0]
+    correlated_rank = 0
+    if result_df.shape[0]>0:
+        correlated_rank = result_df.iloc[-1, 0]
     if correlated_rank >= up_threshold:
         return contravariant
     else:
@@ -388,7 +392,9 @@ def alpha_13_ls(data = None, contravariant = -1., up_threshold=0.8, low_threshol
     result_df = roll_corr(to_roll, window=lag)
     result_df = result_df.dropna()
     result_df = result_df.rank(pct = True)
-    correlated_rank = result_df.iloc[-1, 0]
+    correlated_rank = 0
+    if result_df.shape[0]>0:
+        correlated_rank = result_df.iloc[-1, 0]
     if correlated_rank >= up_threshold:
         return contravariant
     elif correlated_rank <= low_threshold:
@@ -933,7 +939,7 @@ def slope_lo_to_ls(data = None, contravariant = -1., up_trend_threshold=0.8, up_
     min_slope_test = 0.1
     if slope_close>min_slope_test and not slope_rec_close_condition == slope_close_condition:
         print('trouble investigate')
-        assert slope_rec_close_condition == slope_close_condition
+#        assert slope_rec_close_condition == slope_close_condition
 
     if trend_rank > up_trend_threshold and slope_close>0 :
         return contravariant
